=================================
Get assistance in using PyDynamic
=================================

We prepared a collection of tutorials and examples to document, explain and
illustrate the possibilities offered by *PyDynamic*. We will add more and more examples
over time, especially those that are currently included in PyDynamic's codebase
subfolder `examples <https://github.com/PTB-PSt1/PyDynamic/tree/master/examples>`_.

The following links take you to the webpages containing the tutorials' documentation.

Getting started with the tutorials
----------------------------------

* :doc:`Start a notebook server remotely or locally <PyDynamic_tutorials:README>`

Deconvolution
-------------

#. :doc:`Basic measurement data pre-processing <PyDynamic_tutorials:PyDynamic_tutorials/deconvolution/01 Basic measurement data pre-processing>`
#. :doc:`Preparation of calibration data <PyDynamic_tutorials:PyDynamic_tutorials/deconvolution/02 Preparation of calibration data>`
#. :doc:`Interpolation and extrapolation of calibration data <PyDynamic_tutorials:PyDynamic_tutorials/deconvolution/03 Interpolation and extrapolation of calibration data>`
#. :doc:`Calculation of impulse response of hydrophone <PyDynamic_tutorials:PyDynamic_tutorials/deconvolution/04 Calculation of impulse response of hydrophone>`
#. :doc:`Deconvolution in the frequency domain <PyDynamic_tutorials:PyDynamic_tutorials/deconvolution/05 Deconvolution in the frequency domain>`
#. :doc:`Regularized deconvolution <PyDynamic_tutorials:PyDynamic_tutorials/deconvolution/06 Regularized deconvolution>`


Uncertainty
-----------

These tutorials introduce PyDynamic's capabilities of processing time-series with
the propagation of associated measurement uncertainties.

#. :doc:`Basic measurement data pre-processing <PyDynamic_tutorials:PyDynamic_tutorials/uncertainty/01 Basic measurement data pre-processing>`
#. :doc:`Basic interpolation <PyDynamic_tutorials:PyDynamic_tutorials/uncertainty/02 Basic interpolation>`
#. :doc:`Basic extrapolation <PyDynamic_tutorials:PyDynamic_tutorials/uncertainty/03 Basic extrapolation>`
